"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LivePlugins = void 0;
var _analyticsReactNative = require("@segment/analytics-react-native");
var _compat = require("./compat");
var _sandbox = require("./sandbox");
var RNFS = _interopRequireWildcard(require("react-native-fs"));
var _util = require("./util");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const hasEdgeFunction = settings => settings !== undefined && settings !== null && Object.keys(settings).length > 0;
const FILE_PATH = RNFS.DocumentDirectoryPath + '/liveplugin.js';
class LivePlugins extends _analyticsReactNative.UtilityPlugin {
  type = _analyticsReactNative.PluginType.before;
  dependents = [];
  static loaded = false;
  loadEdgeFunction = async settings => {
    if (this.analytics === undefined) {
      return;
    }
    if (!hasEdgeFunction(settings)) {
      return;
    }
    const hasFile = await RNFS.exists(FILE_PATH);
    if (!hasFile) {
      this.analytics?.logger.info('Edge Function has not been downloaded yet. Skipping until settings update');
      return;
    }
    try {
      let js = await RNFS.readFile(FILE_PATH);
      this.compatLayer = new _compat.SegmentClientLivePluginLayer(this.analytics);
      this.dependents.forEach(d => {
        d.prepare(this.compatLayer);
      });
      try {
        // extract functions defined in the js code
        // and attach it to global, so we may call it
        // via the function name
        const functions = (0, _util.extractFunctionNames)(js);
        functions.forEach(f => {
          js += '\nglobal.' + f + ' = ' + f + ';';
        });
        (0, _sandbox.sandboxExecute)(this.compatLayer, js);
        this.dependents.forEach(d => {
          d.readyToStart();
        });
      } catch (e) {
        this.analytics.logger?.warn('Edge Function error:', e);
        // If the liveplugin fails to execute we won't update the version we're running,
        return;
      }
      await this.store?.dispatch(state => {
        return {
          ...state,
          currentVersion: state.edgeFunction?.version
        };
      });
    } catch (e) {
      this.analytics?.logger.warn(`LivePlugin couldn't be loaded: ${JSON.stringify(e)}`);
    }
  };
  async downloadEdgeFunction(downloadURL, version) {
    if (this.analytics === undefined) {
      return;
    }
    try {
      // Download the file
      // 'https://cdn.liveplugin.segment.com/3psnN9oWENuLqmfAtKLcKh/e812b97d-6d21-408f-8533-9582fa8b0ed7.js'
      const response = await fetch(downloadURL);
      const js = await response.text();
      await RNFS.writeFile(FILE_PATH, js);
      await this.store?.dispatch(state => {
        return {
          ...state,
          settings: {
            downloadURL,
            version
          }
        };
      });
      this.analytics.logger.info(`LivePlugin version ${version} downloaded. It will apply after the next app startup`);
      return version;
    } catch (e) {
      this.analytics.logger.warn(`LivePlugin version ${version} failed to download: ${JSON.stringify(e)}`);
    }
    return;
  }
  update(_, _type) {
    if (LivePlugins.loaded) return;
    LivePlugins.loaded = true;
    const edgeFunctionSettings = this.analytics?.edgeFunctionSettings.get();
    if (hasEdgeFunction(edgeFunctionSettings)) {
      const config = edgeFunctionSettings;
      const currentVersion = this.store?.getState().currentVersion;
      if (config.version !== currentVersion) {
        this.analytics?.logger.info(`LivePlugin version ${config.version} found. Currently running version ${currentVersion}.`);
        this.downloadEdgeFunction(config.downloadURL, config.version);
      }
    }
  }
  configure(analytics) {
    this.analytics = analytics;
    const edgeFunctionSettings = analytics?.edgeFunctionSettings.get();
    if (typeof edgeFunctionSettings === 'object' && edgeFunctionSettings != null) {
      this.loadEdgeFunction(edgeFunctionSettings).catch(error => {
        console.error('Error when download edge function:', error);
      });
    }
  }
  shutdown() {
    this.compatLayer?.cleanup();
  }
  addDependent(plugin) {
    this.dependents.push(plugin);
    if (LivePlugins.loaded) {
      plugin.prepare(this.compatLayer);
      plugin.readyToStart();
    }
  }
}
exports.LivePlugins = LivePlugins;
//# sourceMappingURL=liveplugin.js.map