import { AliasEventType, EventPlugin, GroupEventType, GroupTraits, IdentifyEventType, JsonMap, ScreenEventType, SegmentClient, SegmentEvent, TrackEventType, UserTraits } from '@segment/analytics-react-native';
import type { LivePlugin } from './types';
/**
 * Provides a compatibility layer for LivePlugins to Timeline Plugins
 */
export declare class LivePluginAsPlugin extends EventPlugin {
    readonly livePlugin: LivePlugin;
    constructor(livePlugin: LivePlugin);
    execute(event: SegmentEvent): SegmentEvent | Promise<SegmentEvent | undefined> | undefined;
    track(event: TrackEventType): TrackEventType | Promise<TrackEventType | undefined> | undefined;
    identify(event: IdentifyEventType): IdentifyEventType | Promise<IdentifyEventType | undefined> | undefined;
    group(event: GroupEventType): GroupEventType | Promise<GroupEventType | undefined> | undefined;
    alias(event: AliasEventType): AliasEventType | Promise<AliasEventType | undefined> | undefined;
    screen(event: ScreenEventType): ScreenEventType | Promise<ScreenEventType | undefined> | undefined;
    reset(): void;
    flush(): void;
}
export declare class SegmentClientLivePluginLayer {
    private analytics;
    /**
     * Unsubscribe function for new plugin listener
     */
    private unsubscribePluginListener?;
    constructor(analytics: SegmentClient);
    get traits(): UserTraits | GroupTraits;
    get userId(): string | undefined;
    get anonymousId(): string;
    track(event: string, properties?: JsonMap): Promise<void>;
    identify(userId?: string, traits?: UserTraits): Promise<void>;
    screen(title: string, _category?: string, properties?: JsonMap): Promise<void>;
    group(groupId: string, traits?: GroupTraits): Promise<void>;
    alias(newId: string): Promise<void>;
    reset(): Promise<void>;
    flush(): Promise<void>;
    add(livePlugin: LivePlugin): void;
    private addDestinationFunction;
    private addToDestination;
    /**
     * Cleans and removes all background listeners
     */
    cleanup(): void;
    private insertEventOrigin;
}
//# sourceMappingURL=compat.d.ts.map