import type { SegmentClientLivePluginLayer } from './compat';
/**
 * SafeProxy prevents the caller from escaping the sandbox through function, objects, classes
 * Blocks any access to prototype and extensibility (but the user is free to declare new objects, extend classes or call functions)
 *
 * It wraps inner properties in the same SafeProxy to prevent leaking through inner objects
 *
 */
export declare class SafeProxy<T extends object> implements ProxyHandler<T> {
    getPrototypeOf(target: T): object | null;
    setPrototypeOf(_target: T, _value: object | null): boolean;
    defineProperty(_target: T, _property: string | symbol, _attributes: PropertyDescriptor): boolean;
    preventExtensions(_target: T): boolean;
    isExtensible(_target: T): boolean;
    get(target: T, prop: string | symbol, receiver: any): any;
    set(target: T, prop: string | symbol, newValue: any, receiver: any): boolean;
}
/**
 * This function limits the scope of the LivePlugin as most as we can so that they
 * don't pollute our global scope. It clousures only the stuff we want to show
 * to the eval function
 *
 * Use `paramsKeyValue` to export more objects to eval in the format of:
 * { '<alias name>' : <actual instance of the object>}
 *
 * @throws
 *
 * @returns code execution result (if any)
 */
export declare function sandboxExecute(analytics: SegmentClientLivePluginLayer, livePluginCode: string, paramsKeyValue?: {}): any;
//# sourceMappingURL=sandbox.d.ts.map